<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->
**Table of Contents**

- [gdx_lib](#gdx_lib)
- [User Installation](#user-installation)
- [User Documents](#user-documents)
  - [Pre-requisites](#pre-requisites)
- [Development Environment Setup](#development-environment-setup)
  - [First Time Setup](#first-time-setup)
  - [Storing and Managing api keys.](#storing-and-managing-api-keys)
    - [Alternate key management](#alternate-key-management)
  - [Development Tips](#development-tips)
  - [Building docs](#building-docs)
  - [Test Tips](#test-tips)
  - [Release Tips](#release-tips)
  - [Steps: Staging Release](#steps-staging-release)
- [Example User Documentation](#example-user-documentation)
- [GDX Examples](#gdx-examples)
  - [This document provides additional documentation on the examples provided for gdx_lib.](#this-document-provides-additional-documentation-on-the-examples-provided-for-gdx_lib)
  - [Pre-requisites](#pre-requisites-1)
  - [download_datasets.py](#download_datasetspy)
    - [Examples](#examples)
      - [Example 1](#example-1)
      - [Example 2](#example-2)
  - [download_ids.py](#download_idspy)
    - [Examples](#examples-1)
      - [Example 1:](#example-1-1)
      - [Example 2](#example-2-1)
  - [download_resources.py](#download_resourcespy)
      - [Command line examples:](#command-line-examples)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

**Table of Contents**

-   [gdx_lib](#gdx_lib)

-   [User Installation](#user-installation)

-   [Pre-requisites](#pre-requisites)

-   [Development Environment Setup](#development-environment-setup)

-   [First Time Setup](#first-time-setup)

-   [Storing and Managing api keys.](#storing-and-managing-api-keys)

    -   [Alternate key management](#alternate-key-management)

-   [Development Tips](#development-tips)

-   [Building docs](#building-docs)

-   [Test Tips](#test-tips)

**Table of Contents**

-   [gdx_lib](#gdx_lib)

-   [User Installation](#user-installation)

-   [Pre-requisites](#pre-requisites)

-   [Development Environment Setup](#development-environment-setup)

-   [First Time Setup](#first-time-setup)

-   [Storing and Managing api keys.](#storing-and-managing-api-keys)

-   [Development Tips](#development-tips)

-   [Building docs](#building-docs)

[Staging: gdx_lib]

gdx_lib
=======

gdx_lib is a library of classes for accessing GDX Data files. This is the
initial check

Class Diagram

![](media/6d1da09fc4872ebc1ddf4350f6409b39.png)

User Installation
=================

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
pip install gdx_lib --index-url=https://packages.idmod.org/api/pypi/pypi-production/simple --upgrade
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


User Documents
==============

[User
documentation](https://github.com/InstituteforDiseaseModeling/gdx_lib/blob/main/examples/README.md).

Pre-requisites
--------------

-   Python 3.6/3.7 x64

-   The url for the gdx server to use

-   A gdx access key for the desired server. See
    [FAQ](https://dataexchange.gatesfoundation.org/pages/support-index) for
    information on requesting and finding your key

Development Environment Setup
=============================

When setting up your environment for the first time, you can use the following
instructions:

First Time Setup
----------------

1.  Clone the repository: `bash    > git clone
    https://github.com/InstituteforDiseaseModeling/gdx_lib.git`

2.  Create a virtualenv. On Windows, please use venv to create the environment
    `python -m venv gdx_lib` On Unix(Mac/Linux) you can use venv or virtualenv

3.  Activate the virtualenv. For windows `./env/Scripts/activate`

4.  If you are on windows, run `pip install py-make --upgrade --force-reinstall`

5.  Then run `python ./.dev_scripts/bootstrap.py`. This will install all the
    tools.

6.  Then run `pip install -r dev_requirements.txt` .

Storing and Managing api keys.
------------------------------

Api keys are issued to users and permission to access GDX data is dependent on
your key. The user should protect their access key, so you should either keep it
in an environment variable or a secure file.

To use the Gdx API, the user must define environment variable

CKAN_API_KEY = api key  
CKAN_DEFAULT_URL = url

For production GDX, the url = <https://dataexchange.gatesfoundation.org/>

For Test the url is : <https://dataexchange-uat.gatesfoundation.org/>

### Alternate key management

Another way to manage the users key is to use a ‘secret file’, ’ .ckan_profile’.
For linux users this file must be created in their home directory, and
read/write permission must be set for owner only (e.g chmod u=rw .ckan_profile)

For windows system the file must be stored in the users Appdata/Roaming/CKAN
(e.g. c:/Users/\<user\>/AppData/Roaming/CKAN/.ckan_profile) . On windows you
will need to create the CKAN directory in …/AppData/Roaming before creating the
file

An example .ckan_profile is provided in docs/CKAN_Profile_example

Development Tips
----------------

There is a Makefile file available for most common development tasks. Here is a
list of commands

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
clean       -   Clean up temporary files
lint        -   Lint package and tests
test        -   Run All tests
coverage    -   Run tests and generate coverage report that is shown in browser
dist        -   build the distribution
release     -   Push the library to staging artifactory
release_prod -  push the library to production artifactory
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

On Windows, you can use `pymake` instead of `make`

Building docs
-------------

`make docs`

Test Tips
---------

Unit test in the tests folder require the user to create a CKAN Profile file
with a system named gdx.uat (gdx unit test).

The unit test environment also requires the installation of pytest `pip install
pytest`. Note, for windows system you may have to install additional modules.

To run the examples, the library must be built and installed. To build the
library `pymake dist`. The gdx_lib wheel
(`./dist/gdx_lib-<version>-py3-none-any.whl`) can then be installed with pip.

Note if you want to load the library from the staging server, use the following
command:

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
pip install gdx_lib --index-url=https://packages.idmod.org/api/pypi/pypi-staging/simple --upgrade
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Release Tips
------------

To release the software requires a push to the artifactory server
(\$STAGING_REPO_URL or \$PROD_REPO_URL.

Steps: Staging Release
----------------------

Define environment variable TWINE_USERNAME=\<user’s name\>

Define environment variable TWINE_PASSWORD=\<user’s password\>

pymake dist

To push to staging: pymake release

To push to production: pymake release_prod

Alternate Method 1:

pymake dist

To push to staging: make release or

To push to production: make release_prod

In both cases, you will be prompted for your username and password

Example User Documentation
==========================

**Table of Contents**

-   [GDX Examples](#gdx-examples)

-   [This document provides additional documentation on the examples provided
    for
    gdx_lib.](#this-document-provides-additional-documentation-on-the-examples-provided-for-gdx_lib)

-   [Pre-requisites](#pre-requisites)

-   [download_datasets.py](#download_datasetspy)

    -   [Examples](#examples)

    -   [Example 1](#example-1)

    -   [Example 2](#example-2)

-   [download_ids.py](#download_idspy)

    -   [Examples](#examples-1)

    -   [Example 1:](#example-1-1)

    -   [Example 2](#example-2-1)

-   [download_resources.py](#download_resourcespy)

    -   [Command line examples:](#command-line-examples)

GDX Examples
============

This document provides additional documentation on the examples provided for gdx_lib.
-------------------------------------------------------------------------------------

Pre-requisites
--------------

To run the example applications the following pre-requisites are required:

1.  python 3.6 or greater

2.  gdx_lib installed

3.  the Environment variable CKAN_DEFAULT_URL defined to point to the GDX server

4.  the Environment variable CKAN_API_KEY set to your gdx api key

download_datasets.py
--------------------

This example shows how to download one or more datasets from the GDX server.
Note that a dataset can contain one or more resources (files). This tool will
download all files of the dataset. Also, GDX can contain data that are Sensitive
or Very Sensitive, and require that the user understand and acknowledge the
guidelines for the managing and caring for data for sensitive data. Because of
this these tools do not allow the download of sensitive or very sensitive data.

### Examples

There are two ways to download dataset resources, one it to define the datasets
to download on the command line (Example 1 below) the other is to define a .json
file with dataset names and target sub-directory (see dataset_names.json for an
example). Also see example 2 below for run command

In the .json file, if no sub-directory is specified for the dataset the
resources will be saved in the output directory.

#### Example 1

Windows:

python download_datasets.py -o D:/Data/gdx_test "Zip code data" "New York City
Public Transits ride data"

Linux:

python3 download_datasets.py -o \~/Data/gdx_test "Zip code data" "New York City
Public Transits ride data"

#### Example 2

Windows:

python download_datasets.py -o d:/Data/gdx_test -f dataset_name.json

Linux:

python3 download_datasets.py -o \~/Data/gdx_test -f dataset_name.json

download_ids.py
---------------

This example shows how to download one or more datasets from the GDX server
using the dataset id(s). Note that a dataset can contain one or more resources
(files). This tool will download all files of the dataset. Also, GDX can contain
data that are Sensitive or Very Sensitive, and require that the user understand
and acknowledge the guidelines for the managing and caring for data for
sensitive data. Because of this these tools do not allow the download of
sensitive or very sensitive data

### Examples

There are two ways to download dataset resources, one it to define the datasets
ids to download on the command line (Example 1 below) the other is to define a
.json file with dataset ids and target sub-directory (see
dataset_work_items.json for an example). Unlike dataset names, dataset ids are
unique, insuring that the correct dataset is downloaded. The dataset id can be
found at the bottom of the catalog page

Sub-directories will be created in the output directory as needed In the .json
file, if no sub-directory is specified for the dataset the resources will be
saved in the output directory specified.

#### Example 1:

Windows:

python download_ids.py -o D:/Data/gdx_test
"994051af-0766-4a8e-bc73-2ebed4bd3b3b" "2a9e1c19-90fe-4d71-ad7e-9d813c8e7ef9"

Linux:

python3 download_ids.py -o \~/Data/gdx_test
"994051af-0766-4a8e-bc73-2ebed4bd3b3b" "2a9e1c19-90fe-4d71-ad7e-9d813c8e7ef9"

#### Example 2

Windows:

python download_ids.py -o D:/Data/gdx_test -f dataset_ids.json

Linux:

python3 download_ids.py -o \~/Data/gdx_test -f dataset_ids.json

download_resources.py
---------------------

This example will download one or more resources from a dataset. In this example
the user select which resources from the dataset to download. If no resources
are specified, then the entire data set is downloaded. Note: GDX can contain
data that are Sensitive or Very Sensitive, and require that the user understand
and acknowledge the guidelines for the managing and caring for data for
sensitive data. Because of this these tools do not allow the download of
sensitive or very sensitive data

There are two ways to download resources from a dataset, one it to define the
datasets ( -d option) and the resources to download on the command line (Example
1 below) the other is to define a .json file with dataset names, resource name
and target sub-directory (see download_resources.json for and example). Also see
example 2 below for run command. This application allows you to do both at the
same time, download an entire data set, or download specific resources (see
example 3).

In the .json file, if no sub-directory is specified for the dataset the
resources will be saved in the output directory.

#### Command line examples:

Windows:

python download_resources.py -o D:/Data/gdx_test -d "New York City Public
Transits ride data" "MTA Bus Tables_UL2019"

python download_resources.py -o D:/Data/gdx_test -f download_resources.json

python download_resources.py -o D:/Data/gdx_test -f download_resources.json -d
"New York City Public Transits ride data" "MTA Bus Tables_UL2019"

Linux:

python3 download_resources.py -o \~/Data/gdx_test -d "New York City Public
Transits ride data" "MTA Bus Tables_UL2019"

python3 download_resources.py -o \~/Data/gdx_test -f download_resources.json

python3 download_resources.py -o \~/Data/gdx_test -f download_resources.json -d
"New York City Public Transits ride data" "MTA Bus Tables_UL2019"
