#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script for the gdx_lib"""
import sys

from setuptools import setup, find_packages
from distutils.util import convert_path

main_ns = {}
ver_path = convert_path('gdx_lib/version.py')
with open(ver_path) as ver_file:
    exec(ver_file.read(), main_ns)

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('requirements.txt') as requirements_file:
    requirements = requirements_file.read().split("\n")

dev_requirements = ['flake8', 'coverage', 'py-make', 'bump2version', 'twine']
setup_requirements = []
test_requirements = ['pytest', 'pytest-runner', 'pytest-timeout', 'pytest-cache'] + dev_requirements

extras = dict(test=test_requirements, dev=dev_requirements)

authors = [
    ("Dennis Harding", "dharding@idmod.org"),
]

setup(
    author=[author[0] for author in authors],
    author_email=[author[1] for author in authors],
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    description="lib to interface with Foundation gdx system and download data",
    license=open('LICENSE.txt').read(),
    install_requires=requirements,
    long_description=readme,
    include_package_data=True,
    keywords='modeling, IDM',
    name='gdx_lib',
    packages=find_packages(),
    setup_requires=setup_requirements,
    python_requires='>=3.6.*',
    test_suite='tests',
    extras_require=extras,
    version=main_ns['__version__']
)
